==> kubernetes-model-0.1.5-sources.jar: io/fabric8/openshift/api/model/GitBuildSourceFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class GitBuildSourceFluent<T extends GitBuildSourceFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String httpProxy;     String httpsProxy;     String ref;     String uri;     Map<String, Object> additionalProperties = new HashMap();

    public String getHttpProxy(){
    return this.httpProxy;
    }
    public T withHttpProxy( String httpProxy){
    this.httpProxy=httpProxy; return (T) this;
    }
    public String getHttpsProxy(){
    return this.httpsProxy;
    }
    public T withHttpsProxy( String httpsProxy){
    this.httpsProxy=httpsProxy; return (T) this;
    }
    public String getRef(){
    return this.ref;
    }
    public T withRef( String ref){
    this.ref=ref; return (T) this;
    }
    public String getUri(){
    return this.uri;
    }
    public T withUri( String uri){
    this.uri=uri; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }



}

==> kubernetes-model-1.0.9-sources.jar: io/fabric8/openshift/api/model/GitBuildSourceFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class GitBuildSourceFluent<T extends GitBuildSourceFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String httpProxy;     String httpsProxy;     String ref;     String uri;     Map<String, Object> additionalProperties = new HashMap();

    public String getHttpProxy(){
    return this.httpProxy;
    }
    public T withHttpProxy( String httpProxy){
    this.httpProxy=httpProxy; return (T) this;
    }
    public String getHttpsProxy(){
    return this.httpsProxy;
    }
    public T withHttpsProxy( String httpsProxy){
    this.httpsProxy=httpsProxy; return (T) this;
    }
    public String getRef(){
    return this.ref;
    }
    public T withRef( String ref){
    this.ref=ref; return (T) this;
    }
    public String getUri(){
    return this.uri;
    }
    public T withUri( String uri){
    this.uri=uri; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
GitBuildSourceFluent that = (GitBuildSourceFluent) o;
if (httpProxy != null ? !httpProxy.equals(that.httpProxy) :that.httpProxy != null) return false;
if (httpsProxy != null ? !httpsProxy.equals(that.httpsProxy) :that.httpsProxy != null) return false;
if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
